@@ -14,7 +14,7 @@ pub fn serialize(vec: Vec<(String, String)>) -> String {
         string.push_str(&i.1);
         string.push_str(&String::from(","));
 
-        if count != vec.len() {
+        if count < vec.len() {
             string.push_str(",");
         }
 
